# @summary A Puppet module that installs and configures sftpgo.
#
# @param config_hash
# @param docker_images
# @param memory_limit
# @param force_passive_ip
# @param http_port
# @param sftp_port
# @param ftp_port
# @param passive_port_range
# @param ports
# @param volumes
#
# @param environment
# examples:
#   SFTPGO_FTPD__PASSIVE_PORT_RANGE__START=50000
#   SFTPGO_FTPD__PASSIVE_PORT_RANGE__END=50100
#   SFTPGO_WEBDAVD__BINDINGS__0__PORT=10080
#   SFTPGO_GRACE_TIME=10
#
# @example
#   include sftpgo
class sftpgo (
  Optional[Hash] $config_hash = undef,
  Hash $docker_images = {
    'sftpgo' => {
      image     => 'drakkan/sftpgo',
      image_tag => 'latest'
    }
  },
  String[1] $memory_limit = '256m',
  String $force_passive_ip = $facts['networking']['ip'],
  String[1] $http_port = '8080',
  String[1] $sftp_port = '2022',
  String[1] $ftp_port = '2121',
  String[1] $passive_port_range = '50000-50100',
  Array[String] $ports = [
    "${http_port}:${http_port}",
    "${sftp_port}:${sftp_port}",
    "${ftp_port}:${ftp_port}",
    "${passive_port_range}:${passive_port_range}"
  ],
  Array[String] $environment = [
    "SFTPGO_FTPD__BINDINGS__0__FORCE_PASSIVE_IP=${$force_passive_ip}",
    "SFTPGO_FTPD__BINDINGS__0__PORT=${ftp_port}"
  ],
  Array[String] $volumes = [
    'srv_sftpgo:/srv/sftpgo',
    'var_lib_sftpgo:/var/lib/sftpgo'
  ]
) inherits sftpgo::params {
  if $config_hash { include sftpgo::config }
  include sftpgo::docker
  include sftpgo::service
}
